# MSSQL Resource Provider

The MSSQL Resource Provider lets you manage [mssql](https://www.pulumi.com/registry/packages/mssql/) resources.

## Installing

This package is available for several languages/platforms:

### Node.js (JavaScript/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```bash
npm install @pulumiverse/mssql
```

or `yarn`:

```bash
yarn add @pulumiverse/mssql
```

### Python

To use from Python, install using `pip`:

```bash
pip install pulumiverse_mssql
```

### Go

To use from Go, use `go get` to grab the latest version of the library:

```bash
go get github.com/pulumiverse/pulumi-mssql/sdk/go/...
```

### .NET

To use from .NET, install using `dotnet add package`:

```bash
dotnet add package Pulumiverse.Mssql
```

## Reference

For detailed reference documentation, please visit [the Pulumi registry](https://www.pulumi.com/registry/packages/mssql/api-docs/).
